<?php

/**
 * Override or insert variables into the page template for page output.
 *
 * Sets the widths of the main columns of the page.
 */
function elis_preprocess_page(&$variables) {
  // Add information about the number of sidebars.
  if (!empty($variables['page']['sidebar_first']) && !empty($variables['page']['sidebar_second'])) {
    $variables['content_column_class'] = ' class="col-sm-6"';
  }
  elseif (!empty($variables['page']['sidebar_first']) || !empty($variables['page']['sidebar_second'])) {
    $variables['content_column_class'] = ' class="col-sm-9"';
  }
  else {
    $variables['content_column_class'] = ' class="col-sm-12"';
  }

  // Primary nav.
  $variables['primary_nav'] = FALSE;
  if ($variables['main_menu']) {
    // Build links.
    $variables['primary_nav'] = menu_tree(variable_get('menu_main_links_source', 'main-menu'));
    // Provide default theme wrapper function.
    $variables['primary_nav']['#theme_wrappers'] = array('menu_tree__primary');
  }

  // Secondary nav.
  $variables['secondary_nav'] = FALSE;
  if ($variables['secondary_menu']) {
    // Build links.
    $variables['secondary_nav'] = menu_tree(variable_get('menu_secondary_links_source', 'user-menu'));
    // Provide default theme wrapper function.
    $variables['secondary_nav']['#theme_wrappers'] = array('menu_tree__secondary');
  }

  $variables['navbar_classes_array'] = array('navbar');

  if (theme_get_setting('bootstrap_navbar_position') !== '') {
    $variables['navbar_classes_array'][] = 'navbar-' . theme_get_setting('bootstrap_navbar_position');
  }
  else {
    $variables['navbar_classes_array'][] = 'container';
  }
  if (theme_get_setting('bootstrap_navbar_inverse')) {
    $variables['navbar_classes_array'][] = 'navbar-inverse';
  }
  else {
    $variables['navbar_classes_array'][] = 'navbar-default';
  }
  
  if (isset($variables['node'])) {
    // If the node type is "blog_madness" the template suggestion will be "page--blog-madness.tpl.php".
    $variables['theme_hook_suggestions'][] = 'page__'. $variables['node']->type;    
  }
  
  // custom not fund pages
  // now it not work
  $header = drupal_get_http_header("status"); 
  if($header == "404 Not Found") {     
    $variables['theme_hook_suggestions'][] = 'page__404';
  }
  if($header == "403 Forbidden") {
    $variables['theme_hook_suggestions'][] = 'page__403';
  }
  
  // add theme chromeColor and textColor
  $variables['chromeColor'] = '#0981B3';
  $variables['textColor'] = '#FFFFFF';
  $variables['isHeaderVisible'] = true;
  if (theme_get_setting("elis_chrome_color")) $variables['chromeColor'] = check_plain(theme_get_setting("elis_chrome_color"));
  if (theme_get_setting("elis_text_color")) $variables['textColor'] = check_plain(theme_get_setting("elis_text_color"));
  
  $variables['sidebarPrimaryChromeColor'] = $variables['chromeColor'];
  $variables['sidebarPrimaryTextColor'] = $variables['textColor'];
  $variables['sidebarSecondaryChromeColor'] = $variables['chromeColor'];
  $variables['sidebarSecondaryTextColor'] = $variables['textColor'];
  
  if (module_exists('elis')) {
    $elis_config = isset($GLOBALS['ElisConfig']) ? $GLOBALS['ElisConfig'] : ElisConfig::getDefaultConfig();
    $variables['chromeColor'] = isset($GLOBALS['elis_chrome_color']) ? check_plain($GLOBALS['elis_chrome_color']) : check_plain($elis_config->chromeColor);
    $variables['textColor'] = isset($GLOBALS['elis_text_color']) ? check_plain($GLOBALS['elis_text_color']) : check_plain($elis_config->textColor);
    $variables['headerHeight'] = isset($elis_config->headerHeight) ? check_plain($elis_config->headerHeight) : '144px';
    $variables['isHeaderVisible'] = $elis_config->isHeaderVisible;
    if (null != $elis_config->sidebarPrimaryChromeColor) $variables['sidebarPrimaryChromeColor'] = check_plain($elis_config->sidebarPrimaryChromeColor);
    if (null != $elis_config->sidebarPrimaryTextColor) $variables['sidebarPrimaryTextColor'] = check_plain($elis_config->sidebarPrimaryTextColor);
    $variables['sidebarPrimaryVisibility'] =  (null != $elis_config->sidebarPrimaryVisibility) ? check_plain($elis_config->sidebarPrimaryVisibility) : 'visible';
    if (null != $elis_config->sidebarSecondaryChromeColor) $variables['sidebarSecondaryChromeColor'] = check_plain($elis_config->sidebarSecondaryChromeColor);
    if (null != $elis_config->sidebarSecondaryTextColor) $variables['sidebarSecondaryTextColor'] = check_plain($elis_config->sidebarSecondaryTextColor);
    $variables['sidebarSecondaryVisibility'] = (null != $elis_config->sidebarSecondaryVisibility) ? check_plain($elis_config->sidebarSecondaryVisibility) : 'visible';
    if (null != $elis_config->catalogChromeColor) $variables['catalogChromeColor'] = check_plain($elis_config->catalogChromeColor);
    if (null != $elis_config->catalogTextColor) $variables['catalogTextColor'] = check_plain($elis_config->catalogTextColor);
    
    // pageBackgroundUrl not for all pages, only for nodes
    $variables['pageBackgroundUrl'] = null;
    if (null != $elis_config->pageBackgroundUrl) {
      $menu_item = menu_get_item();
      if (is_array($menu_item) && isset($menu_item['path'])) {
        switch ($menu_item['path']) {
          case 'node/%':
          case 'user/%/library':
          case 'user/%/catalog':
          case 'user/%/recommendation':
          case 'user/%/history':
            if (is_string($elis_config->pageBackgroundUrl) && valid_url($elis_config->pageBackgroundUrl)) {
              $variables['pageBackgroundUrl'] = $elis_config->pageBackgroundUrl;
            } else if (is_array($elis_config->pageBackgroundUrl)) {
              $pageBackgroundUrlIndex = rand(0, (count($elis_config->pageBackgroundUrl)-1));
              if (valid_url($elis_config->pageBackgroundUrl[$pageBackgroundUrlIndex])) {
                $variables['pageBackgroundUrl'] = $elis_config->pageBackgroundUrl[$pageBackgroundUrlIndex];
              }
            }
            break;
        }
      }
    }
  }
  
  // add orgs 
  if (class_exists("ElisOrg")) {
    $account = user_load($GLOBALS['user']->uid);
    $variables['orgs'] = ElisOrg::getOrganizationsForUser($account);
    if ($variables['orgs'] == false) {
      $variables['orgs'] = ElisOrg::findOrganizationsForIp();
    }
  }
}


require_once 'templates/menu/menu-link.func.php';
require_once 'templates/menu/menu-local-task.func.php';
require_once 'templates/menu/menu-tree.func.php';

require_once 'templates/system/item-list.func.php';
require_once 'templates/system/button.vars.php';

//require_once 'templates/file/file-managed-file.func.php';
//require_once 'templates/file/file-widget-multiple.func.php';
//require_once 'templates/file/file-widget.func.php';



/**
 * hook_checkbox
 * @param type $variables
 * @return type
 */
function elis_checkbox($variables) {
  $element = $variables['element'];
  $element['#attributes']['type'] = 'checkbox';
  element_set_attributes($element, array('id', 'name','#return_value' => 'value'));

  // Unchecked checkbox has #value of integer 0.
  if (!empty($element['#checked'])) {
    $element['#attributes']['checked'] = 'checked';
  }
  _form_set_class($element, array('form-checkbox'));

  return '<label><input' . drupal_attributes($element['#attributes']) . ' /></label>';
}