<?php
/**
 * @file
 * Default theme implementation to display a single Drupal page.
 *
 * The doctype, html, head and body tags are not in this template. Instead they
 * can be found in the html.tpl.php template in this directory.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $directory: The directory the template is located in, e.g. modules/system
 *   or themes/bartik.
 * - $is_front: TRUE if the current page is the front page.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or
 *   prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 *
 * Navigation:
 * - $main_menu (array): An array containing the Main menu links for the
 *   site, if they have been configured.
 * - $secondary_menu (array): An array containing the Secondary menu links for
 *   the site, if they have been configured.
 * - $breadcrumb: The breadcrumb trail for the current page.
 *
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title: The page title, for use in the actual HTML content.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 * - $messages: HTML for status and error messages. Should be displayed
 *   prominently.
 * - $tabs (array): Tabs linking to any sub-pages beneath the current page
 *   (e.g., the view and edit tabs when displaying a node).
 * - $action_links (array): Actions local to the page, such as 'Add menu' on the
 *   menu administration interface.
 * - $feed_icons: A string of all feed icons for the current page.
 * - $node: The node object, if there is an automatically-loaded node
 *   associated with the page, and the node ID is the second argument
 *   in the page's path (e.g. node/12345 and node/12345/revisions, but not
 *   comment/reply/12345).
 *
 * Regions:
 * - $page['content']: The main content of the current page.
 * - $page['sidebar_first']: Items for the first sidebar.
 * - $page['sidebar_second']: Items for the second sidebar.
 * - $page['header']: Items for the header region.
 * - $page['footer']: Items for the footer region.
 *
 * @see bootstrap_preprocess_page()
 * @see template_preprocess()
 * @see template_preprocess_page()
 * @see bootstrap_process_page()
 * @see template_process()
 * @see html.tpl.php
 *
 * @ingroup themeable
 */
?>

<style>
  .sidebar-primary-theme, #sidebar-primary.sidebar-primary-theme {
    color: <?php print $sidebarPrimaryTextColor;?>;    
    background: <?php print $sidebarPrimaryChromeColor;?>;
  }
  .sidebar-secondary-theme, #sidebar-secondary.sidebar-secondary-theme {
    color: <?php print $sidebarSecondaryTextColor;?>;    
    background: <?php print $sidebarSecondaryChromeColor;?>;
  }
  <?php if ($pageBackgroundUrl != null) {
    print "html { background: url($pageBackgroundUrl) no-repeat center / cover #FFFFFF;}"; 
  }?>
</style>

<div style="width:100%; height: auto; overflow: auto; display:flex;">
  
  <div class='hidden' id='sidebar-overflow-screen' style='width:100%; height: 100%; position:absolute; background: rgba(0,0,0,.7); z-index:19;'></div>
  
  <!-- primary sidebar -->
  <script>
    (function(){
      var isHidden = false;
      if (window.innerWidth < 1024) { // on small screen always start hidden
        isHidden = true;
      } else if (localStorage.getItem('sidebar-primary-hidden') != null ) {
         if (localStorage.getItem('sidebar-primary-hidden') == 'hidden') {
           isHidden = true;
         }
      }
      <?php if (in_array($sidebarPrimaryVisibility, array("invisible", "hidden"))) : ?>
        isHidden = true;
      <?php endif; ?>
      if (isHidden) {
        document.write('<aside class="sidebar sidebar-primary-theme hidden" id="sidebar-primary">');
      } else {
        document.write('<aside class="sidebar sidebar-primary-theme" id="sidebar-primary">');
      }
    })();
  </script>
  <noscript>
  <aside class="sidebar sidebar-primary-theme" id="sidebar-primary">
  </noscript>
    
    
    
    
    
    <div class="menu sidebar-menu-first sidebar" data-nosnippet>
      
      <?php if (!empty($page['sidebar_first'])): ?>
        <aside role="complementary">
          <?php print render($page['sidebar_first']); ?>
        </aside>  <!-- /#sidebar-first -->
        
      <?php endif; ?>
    
    </div>  
    
    <!-- footer -->
    <footer class="footer footer-primary">
      <?php print render($page['footer_primary']); ?>
      <a href="https://lib.elibsystem.ru" target="_blank" class="elis-footer-logo" alt="Библиотека ELiS" title="Библиотека ELiS <?php if (variable_get('elis_license_title', false) != false) { print " лицензирована на " . variable_get('elis_license_title', false); }  ?>" aria-label="Перейти на сайт разработчика Библиотеки ELiS" rel="noopener"><img src="<?php echo $GLOBALS['base_url'];?>/sites/all/themes/elis/img/logo-36.png" alt="ELiS Library logo"/></a>
    </footer>
    
  </aside>
  
  <!-- end primary sidebar -->
  
  
  
  <!-- main content -->
  
  
  
    <div class="pages" style="flex-grow: 1; flex-shring: 1; flex-basis: 60%;">
      
      <?php if (isset($textColor) && isset($chromeColor)) { ?>
        <style>
          #about.well.page.active {
            padding-top: 0px;
            padding-bottom: 18px;
          }
          .page-header, .page-header icon, .top-bar {
            color: <?php print $textColor; ?>;
            background: <?php print $chromeColor; ?>;
          }
        </style>
      <?php } ?>
        
      
      <!-- top bar -->  
      <?php if (isset($page['header'])) : ?>
        <div class="top-bar" data-nosnippet>
          <?php print render($page['header']); ?>
        </div>  
      <?php endif ?>
        
      <?php if ($isHeaderVisible): ?>
        <header data-nosnippet>
          <?php if ($logo && empty($GLOBALS['elis_header'])): ?>  
            <div class="logo-img-container">
              <img class="logo" src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>" usemap="#homemap"/>  
              <map name="homemap">
                <area shape="rect" coords="0,0,200,<?php echo $headerHeight;?>" href="<?php echo $GLOBALS['base_url'];?>" alt="home">
              </map>
            </div>
          <?php endif; ?>
          <?php if (!empty($GLOBALS['elis_header'])) : ?>
            <?php echo $GLOBALS['elis_header']; ?>
          <?php endif; ?>

          <div class="header-panel shadow-z-2" data-nosnippet style='background-color: <?php print check_plain($chromeColor);?>; height: <?php print $headerHeight; ?>;'>
            <div class="container-fluid">
              <div class="row">
                <div class="col-xs-3">
                  <?php if (!empty($site_name)): ?>
                    <a class="name navbar-brand" href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>"><?php print check_plain($site_name); ?></a>
                  <?php endif; ?>        
                </div>
              </div>
            </div>
          </div>
        </header>  
      <?php endif ?>
        
        
        
        
        
        
      
      
      
      <?php print render($title_prefix); ?>
      
      <?php if (!empty($title)): ?>
        <div class="page-header">
          <?php if ($sidebarPrimaryVisibility != "invisible") : ?>
            <icon class="glyphicon glyphicon-menu-hamburger withripple" data-sidebar="#sidebar-primary"></icon>
          <?php endif; ?>
          <h1>
          <?php print $title; ?>
          </h1>
          <?php if ($sidebarSecondaryVisibility != "invisible") : ?>
            <icon class="glyphicon glyphicon-menu-hamburger withripple" data-sidebar="#sidebar-secondary"></icon>
          <?php endif; ?>
        </div>
      <?php endif; ?>
      
      <?php print render($title_suffix); ?>
      
      <div>  
        <div class="page active" id="about">         
          
          <!-- <section<?php print $content_column_class; ?>> -->
          
            <?php if (!empty($page['highlighted'])): ?>
              <div><?php print render($page['highlighted']); ?></div>
            <?php endif; ?>
            
            
            <?php if (!empty($tabs)): ?>
              <div
                <?php print "style='color: {$textColor}; background-color: {$chromeColor}; box-shadow: rgba(0, 0, 0, 0.4) 0px 8px 8px 0px; margin-bottom: 8px;'";?>
              >
                <?php print render($tabs); ?>
              </div>
            <?php endif; ?>
            
            <?php if (!empty($breadcrumb)): print $breadcrumb; endif;?>
            
          <section id="main-content">
              
            <?php print $messages; ?>
            
            <?php if (!empty($page['help'])): ?>
              <?php print render($page['help']); ?>
            <?php endif; ?>
            <?php if (!empty($action_links)): ?>
              <ul class="action-links"><?php print render($action_links); ?></ul>
            <?php endif; ?>
            <main>
              <?php print render($page['content']); ?>
            </main>
          </section>
        
        </div>
        
      </div> <!-- end col-xs-10 -->
      
      <footer class="footer-main">
        <?php if (variable_get('elis_license_title', false) != false) {
          print "<div style='padding: 1em;'><a href='https://elibsystem.ru' target='_blank' title='Лицензировано на " . variable_get('elis_license_title', false) . "'>" . variable_get('elis_license_title', false) . "</a></div>";
        } ?>
        <?php print render($page['footer']); ?>
      </footer>
    
    </div> <!-- end pages col-xs-9 -->  
    
  <!-- end main content -->
  
  
  <!-- secondary sidebar -->
  <script>
    (function(){
      var isHidden = false;
      if (window.innerWidth < 1024) {
        isHidden = true;
      } else if (localStorage.getItem('sidebar-secondary-hidden') != null) {
        if (localStorage.getItem('sidebar-secondary-hidden') == 'hidden') {
          isHidden = true;
        }
      }
      <?php if (in_array($sidebarSecondaryVisibility,array("invisible","hidden"))) : ?>
        isHidden = true;
      <?php endif; ?>
      if (isHidden) {
        document.write('<aside class="sidebar hidden sidebar-secondary-theme" id="sidebar-secondary" data-nosnippet>');
      } else {
        document.write('<aside class="sidebar sidebar-secondary-theme" id="sidebar-secondary" data-nosnippet>');
      }
    })();
  </script>
  <noscript>
    <aside class="sidebar sidebar-secondary-theme" id="sidebar-secondary" data-nosnippet>
  </noscript>
    
    <div>
        <?php if (!empty($page['sidebar_second'])): ?>
          <div class="sidebar sidebar-menu-second menu visible-lg visible-md visible-sm visible-xs">                    
            <aside role="complementary">
              <?php print render($page['sidebar_second']); ?>
            </aside>  <!-- /#sidebar-second -->          
          </div>
        <?php endif; ?>
    </div>
  </aside>
  
  <!-- end secondary sidebar -->
  
</div>












<div class="container-fluid main">
  <div class="row">
    
    
  </div> <!-- end row -->
</div>   <!-- end confainer-fluid main -->



<?php if (function_exists("get_virtual_keyboard_initialize_code_elis")) echo get_virtual_keyboard_initialize_code_elis(); ?>
